======
Struct
======

The following methods are available under the `expr.struct` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.struct.field
    Expr.struct.rename_fields
